searchData={"items":[{"type":"module","title":"Transmogrify","doc":"Accepts data with different shapes and changes them to an expected shape, such\nas switching keys in a map to camel case, or all string keys to atom keys, etc.\n\nThree primary sections:\n\n* [Transmogrifier](Transmogrify.Transmogrifier.html#transmogrify/2) — convert maps and list keys and values.\n* [As](Transmogrify.As.html) — Simple data polymorphic conversions (as_atom/1) for example.\n* Case and Path conversions (camelcase/snakecase, etc) — see below","ref":"Transmogrify.html"},{"type":"function","title":"Transmogrify.camelcase/1","doc":"","ref":"Transmogrify.html#camelcase/1"},{"type":"function","title":"Transmogrify.modulename/1","doc":"","ref":"Transmogrify.html#modulename/1"},{"type":"function","title":"Transmogrify.pascalcase/1","doc":"","ref":"Transmogrify.html#pascalcase/1"},{"type":"function","title":"Transmogrify.pathname/1","doc":"","ref":"Transmogrify.html#pathname/1"},{"type":"function","title":"Transmogrify.snakecase/1","doc":"","ref":"Transmogrify.html#snakecase/1"},{"type":"function","title":"Transmogrify.transmogrify/2","doc":"","ref":"Transmogrify.html#transmogrify/2"},{"type":"module","title":"Transmogrify.As","doc":"Polymorphic data transforms — accepts many input forms and tries to put\nthem into the expected form.\n\nEasiest use:\n```elixir\niex> import Transmogrify.As\niex> as_int(\"10\")\n{:ok, 10}\niex> as_int!(10.0)\n10\n```","ref":"Transmogrify.As.html"},{"type":"function","title":"Transmogrify.As.as_atom/1","doc":"Accept various data forms and assures they are atoms.\n\nWARNING: Make sure inputs being called are not using user-submitted data;\nor this may exhaust the atoms table.\n\n```elixir\niex> as_atom(\"long ugly thing prolly\")\n{:ok, :\"long ugly thing prolly\"}\niex> as_atom(\"as_atom\")\n{:ok, :as_atom}\niex> as_atom(:atom)\n{:ok, :atom}\niex> as_atom([\"as_atom\", \"another\"])\n{:ok, [:as_atom, :another]}\niex> as_atom('test')\n{:ok, :test}\niex> as_atom(:atom)\n{:ok, :atom}\n```","ref":"Transmogrify.As.html#as_atom/1"},{"type":"function","title":"Transmogrify.As.as_atom!/1","doc":"Accept various data forms and assures they are atoms.\n\nWARNING: Make sure inputs being called are not using user-submitted data;\nor this may exhaust the atoms table.\n\n```elixir\niex> as_atom!(\"long ugly thing prolly\")\n:\"long ugly thing prolly\"\niex> as_atom!(\"as_atom\")\n:as_atom\niex> as_atom!(:atom)\n:atom\niex> as_atom!([\"as_atom\", \"another\"])\n[:as_atom, :another]\niex> as_atom!('test')\n:test\niex> as_atom!(:atom)\n:atom\niex> as_atom!({:oops})\n** (ArgumentError) argument error\n```","ref":"Transmogrify.As.html#as_atom!/1"},{"type":"function","title":"Transmogrify.As.as_existing_atom/1","doc":"Accept various data forms and assures they are atoms (from the existing\natoms table). See String.to_existing_atom/1 for more details.\n\n```elixir\niex> as_existing_atom(\"long ugly thing prolly\")\n{:ok, :\"long ugly thing prolly\"}\niex> as_existing_atom(\"non_existing_atom\")\n:error\niex> as_existing_atom(\"as_existing_atom\")\n{:ok, :as_existing_atom}\niex> as_existing_atom(:atom)\n{:ok, :atom}\niex> as_existing_atom([\"as_existing_atom\", \"another\"])\n{:ok, [:as_existing_atom, :another]}\niex> as_existing_atom(:atom)\n{:ok, :atom}\n```","ref":"Transmogrify.As.html#as_existing_atom/1"},{"type":"function","title":"Transmogrify.As.as_existing_atom!/1","doc":"Accept various data forms and assures they are atoms.\n\nWARNING: Make sure inputs being called are not using user-submitted data;\nor this may exhaust the atoms table.\n\n```elixir\niex> as_existing_atom!(\"long ugly thing prolly\")\n:\"long ugly thing prolly\"\niex> as_existing_atom!(\"as_existing_atom\")\n:as_existing_atom\niex> as_existing_atom!(:atom)\n:atom\niex> as_existing_atom!([\"as_existing_atom\", \"another\"])\n[:as_existing_atom, :another]\niex> as_existing_atom!(:atom)\n:atom\n\niex> as_existing_atom!({:oops})\n** (ArgumentError) argument error\n\niex> as_existing_atom!(\"non_existing_atom\")\n** (ArgumentError) argument error\n```","ref":"Transmogrify.As.html#as_existing_atom!/1"},{"type":"function","title":"Transmogrify.As.as_float/1","doc":"Accept strings, floats, and ints, and assure the result is either\nan float (parsed if necessary) or an error.\n\n```elixir\niex> as_float(10.52)\n{:ok, 10.52}\niex> as_float(10)\n{:ok, 10.0}\niex> as_float(\"10.5\")\n{:ok, 10.5}\niex> as_float(\".55\")\n{:ok, 0.55}\niex> as_float(\"tardis\")\n:error\n```","ref":"Transmogrify.As.html#as_float/1"},{"type":"function","title":"Transmogrify.As.as_float!/2","doc":"Accept strings, floats, and ints, and assure the result is either\nan float (parsed if necessary) or return the specified default (which\nis `0.0` if unspecified)\n\n```elixir\niex> as_float!(10.0)\n10.0\niex> as_float!(10)\n10.0\niex> as_float!(\"10.0\")\n10.0\niex> as_float!(\"tardis\", 9.0)\n9.0\n```","ref":"Transmogrify.As.html#as_float!/2"},{"type":"function","title":"Transmogrify.As.as_int/1","doc":"Accept strings, floats, and ints, and assure the result is either\nan int (parsed if necessary) or an error.\n\n```elixir\niex> as_int(10)\n{:ok, 10}\niex> as_int(10.0)\n{:ok, 10}\niex> as_int(\"10\")\n{:ok, 10}\niex> as_int(\"tardis\")\n:error\niex> as_int(:foo)\n:error\n```","ref":"Transmogrify.As.html#as_int/1"},{"type":"function","title":"Transmogrify.As.as_int!/2","doc":"Accept strings, floats, and ints, and assure the result is either\nan int (parsed if necessary) or return the specified default (which\nis `0` if unspecified)\n\n```elixir\niex> as_int!(10)\n10\niex> as_int!(10.0)\n10\niex> as_int!(\"10\")\n10\niex> as_int!(\"tardis\", 9)\n9\niex> as_int!(:foo, 8)\n8\n```","ref":"Transmogrify.As.html#as_int!/2"},{"type":"function","title":"Transmogrify.As.as_key/1","doc":"Accept atom or string.\nIf string, run through snakecase and convert to atom.\nIf atom, assume this is already done.\n\niex> as_key(\"thiskey\")\n:thiskey\niex> as_key(\"this key\")\n:\"this key\"\niex> as_key(:thisKey)\n:thisKey\niex> as_key(:this_key)\n:this_key","ref":"Transmogrify.As.html#as_key/1"},{"type":"function","title":"Transmogrify.As.as_number/1","doc":"Accept strings, floats, and ints, and assure the result is either\na float or int (parsed if necessary) or an error.\n\n```elixir\niex> as_number(10.52)\n{:ok, 10.52}\niex> as_number(10)\n{:ok, 10}\niex> as_number(\"10.5\")\n{:ok, 10.5}\niex> as_number(\".55\")\n{:ok, 0.55}\niex> as_number(\"tardis\")\n:error\n```","ref":"Transmogrify.As.html#as_number/1"},{"type":"function","title":"Transmogrify.As.as_number!/2","doc":"Accept strings, floats, and ints, and assure the result is either\na float or int (parsed if necessary) or return the specified default (which\nis `0` if unspecified)\n\n```elixir\niex> as_number!(10.0)\n10.0\niex> as_number!(10)\n10\niex> as_number!(\"10.0\")\n10.0\niex> as_number!(\"tardis\", 9.0)\n9.0\n```","ref":"Transmogrify.As.html#as_number!/2"},{"type":"module","title":"Transmogrify.Camelcase","doc":"Convert strings to CamelCase","ref":"Transmogrify.Camelcase.html"},{"type":"function","title":"Transmogrify.Camelcase.convert/1","doc":"Convert a string to `camelCase`, usually when originally `snake_case`, using\nthe following rules:\n\n  * ascii alphabetic letters immediately following an underscore are capitalized\n  * underscores are removed\n  * existing case and other characters are preserved in all other cases\n\nTODO: xref common feels around camelcase — spaces? other chars?\n\n```elixir\niex> convert(\"_camel___case__\")\n\"camelCase\"\niex> convert(\"camel_case\")\n\"camelCase\"\niex> convert(\"camel_9case\")\n\"camel9case\"\niex> convert(\"camel_case\")\n\"camelCase\"\niex> convert(\"CamelCASE\")\n\"CamelCASE\"\niex> convert(\"Camel_CASE\")\n\"CamelCASE\"\niex> convert(\"CamelCase\")\n\"CamelCase\"\n```","ref":"Transmogrify.Camelcase.html#convert/1"},{"type":"module","title":"Transmogrify.Modulename","doc":"Convert file/paths to Elixir ModuleName","ref":"Transmogrify.Modulename.html"},{"type":"function","title":"Transmogrify.Modulename.convert/1","doc":"Convert a `path/module_name/string` to Elixir's `Path.ModuleName.String`,\nusing the following rules similar to PascalCase:\n\n  * first letter is always capitalized\n  * ascii alphabetic letters immediately following an underscore are capitalized\n  * underscores are removed\n  * slashes are converted to dots\n  * existing case and other characters are preserved in all other cases\n\n```elixir\niex> convert(\"MODULENAME\")\n\"MODULENAME\"\niex> convert(\"_module___name__\")\n\"ModuleName\"\niex> convert(\"module_name\")\n\"ModuleName\"\niex> convert(\"module_name\")\n\"ModuleName\"\niex> convert(\"module_name\")\n\"ModuleName\"\niex> convert(\"ModuleNAME\")\n\"ModuleNAME\"\niex> convert(\"Module_NAME\")\n\"ModuleNAME\"\niex> convert(\"ModuleName\")\n\"ModuleName\"\niex> convert(\"Module Name\")\n\"Module Name\"\niex> convert(\"module/name/here\")\n\"Module.Name.Here\"\niex> convert(\"module_9name.here\")\n\"Module9name.Here\"\niex> convert(Module.Name)\n\"Module.Name\"\n```\n\nnote: Original code from `Macro.camelize/1` with minor changes:\n\n* underscore followed by capital letter is treated the same as lowercase letter\n  (the underscore is removed and the letter is capitalized)\n* existing dots are treated the same as slashes (following letter is capitalized)","ref":"Transmogrify.Modulename.html#convert/1"},{"type":"module","title":"Transmogrify.Pascalcase","doc":"Convert strings to PascalCase","ref":"Transmogrify.Pascalcase.html"},{"type":"function","title":"Transmogrify.Pascalcase.convert/1","doc":"Convert a string to `camelCase`, usually when originally `snake_case`, using\nthe following rules:\n\n  * first letter is always capitalized\n  * ascii alphabetic letters immediately following an underscore are capitalized\n  * underscores are removed\n  * existing case and other characters are preserved in all other cases\n\n```elixir\niex> convert(\"PASCALCASE\")\n\"PASCALCASE\"\niex> convert(\"_pascal___case__\")\n\"PascalCase\"\niex> convert(\"pascal_case\")\n\"PascalCase\"\niex> convert(\"pascal_case\")\n\"PascalCase\"\niex> convert(\"PascalCASE\")\n\"PascalCASE\"\niex> convert(\"Pascal_CASE\")\n\"PascalCASE\"\niex> convert(\"PascalCase\")\n\"PascalCase\"\niex> convert(\"pascal_9case\")\n\"Pascal9case\"\n```","ref":"Transmogrify.Pascalcase.html#convert/1"},{"type":"module","title":"Transmogrify.Pathname","doc":"Convert Elixir ModuleName to file/paths.","ref":"Transmogrify.Pathname.html"},{"type":"function","title":"Transmogrify.Pathname.convert/1","doc":"Convert an Elixir's `Path.ModuleName.String` to `path/module_name/string`,\nusing the following rules:\n\n  * `PascalCase` to `snake_case` rules apply\n  * dots are converted to slashes\n  * \"Elixir.\" prefix that exists on elixir module atoms is removed\n\n```elixir\niex> convert(\"Module\")\n\"module\"\niex> convert(\"ModuleName\")\n\"module_name\"\niex> convert(\"MODULENAME\")\n\"modulename\"\niex> convert(\"ModuleName\")\n\"module_name\"\niex> convert(\"ModuleName.Here\")\n\"module_name/here\"\niex> convert(\"path/name/here\")\n\"path/name/here\"\niex> convert(Transmogrify.Pathname)\n\"transmogrify/pathname\"\niex> convert(\"A.AcronymNAME\")\n\"a/acronym_name\"\n```\n\nnote: Original code from Macro.underscore()","ref":"Transmogrify.Pathname.html#convert/1"},{"type":"module","title":"Transmogrify.Snakecase","doc":"Convert strings to snake_case","ref":"Transmogrify.Snakecase.html"},{"type":"function","title":"Transmogrify.Snakecase.convert/1","doc":"Convert a string to `snake_case`, usually when originally `PascalCase` or\n`CamelCase`, using the following rules:\n\n  * dashes are treated the same as underscores\n  * uppercase ascii alphabetic letters are lowercased, and prefixed with\n    an underscore, except when they are the first letter.\n  * duplicate underscores are removed\n  * ACRONYMS are preserved\n  * other characters are preserved in all other cases\n\nSimilar to Pathname, except `.` is not converted to `/`, and dashes are\ncoverted to underbars\n\n```elixir\niex> convert(\"value-dashed\")\n\"value_dashed\"\niex> convert(\"Value\")\n\"value\"\niex> convert(\"vaLue\")\n\"va_lue\"\niex> convert(\"VALUE\")\n\"value\"\niex> convert(\"vaLUE\")\n\"va_lue\"\niex> convert(\"-vaLUE\")\n\"va_lue\"\niex> convert(\"_va___LUE\")\n\"va_lue\"\n```","ref":"Transmogrify.Snakecase.html#convert/1"},{"type":"module","title":"Transmogrify.Transmogrifier","doc":"Convert keys and values in maps and lists of maps","ref":"Transmogrify.Transmogrifier.html"},{"type":"function","title":"Transmogrify.Transmogrifier.transmogrify/2","doc":"Primary function for transmogrifying maps and lists of data that may include maps.\n\n# Options\n\n* `key_convert:` — convert types on keys in maps\n  - `:none` | `nil` (default) — do not convert key types\n  - `:atom` — make all binary/string keys into atoms\n  - `:semi_atom` - make binary/string keys starting with `:` into atoms\n  - `:string` — make all keys into binary/strings\n* `value_convert:` — convert types on values in maps\n  - `:none` | `nil` (default) — do not convert key types\n  - `:atom` — make all binary/string keys into atoms\n  - `:semi_atom` - make binary/string keys starting with `:` into atoms\n  - `:string` — make all keys into binary/strings\n* `key_case:` — convert case on keys in maps\n  - `nil` (default) — do not alter case\n  - `:snake` — convert keys into `snake_case`\n  - `:camel` — convert keys into `camelCase`\n  - `:pascal` — convert keys into `PascalCase`\n* `value_case:` — convert case on values in maps\n  - `nil` (default) — do not alter case\n  - `:snake` — convert keys into `snake_case`\n  - `:camel` — convert keys into `camelCase`\n  - `:pascal` — convert keys into `PascalCase`\n* `deep:` `false` | `true` (default) — recurse full depth of maps/lists or not\n* `clean_nil:` `false` (default) | `true` — remove list/map entry if value is nil\n* `clean_empty_list:` `false` (default) | `true`  — remove list/map entry if zero-length list\n* `clean_empty_string:` `false` (default) | `true` — remove list/map entry if zero-length string\n\n# Examples\n\n```elixir\niex> transmogrify(%{\"Tardis\" => %{\"Key\" => 10}, \"is\" => 2, \"The.Color\" => \"blue\"}, key_convert: :atom)\n%{Tardis: %{Key: 10}, is: 2, \"The.Color\": \"blue\"}\n\niex> transmogrify(%{\"Tardis\" => %{\"Key\" => 10}, \"is\" => 2, \"The.Color\" => \"blue\"}, key_convert: :atom, deep: false)\n%{Tardis: %{\"Key\" => 10}, is: 2, \"The.Color\": \"blue\"}\n\niex> transmogrify(%{\"Sonic\" => 1, \"ScrewDriver\" => \":thIrd\"}, key_convert: :atom, key_case: :snake, value_convert: :atom, value_case: :snake)\n%{sonic: 1, screw_driver: :th_ird}\n\niex> transmogrify([%{ :thisCase => 1, \"thatCase\" => 2 }], key_case: :snake, key_convert: :none)\n[%{ :this_case => 1, \"that_case\" => 2}]\n\niex> transmogrify([%{ :this_case => 1, \"that_case\" => 2 }], key_case: :camel, key_convert: :none)\n[%{ :thisCase => 1, \"thatCase\" => 2}]\n\niex> transmogrify([\n...>     %{a: 1,\n...>       b: [\"red\", nil, \"\", [], \":green\"],\n...>       c: [], d: nil, e: \"\",\n...>       f: %{TarVis: \"blue\"},\n...>       j: \":sonic\"}\n...>   ],\n...>   key_case: :snake, key_convert: :atom,\n...>   value_case: :snake, value_convert: :none,\n...>   clean_nil: true, clean_empty_list: true, clean_empty_string: true\n...> )\n[%{a: 1, b: [\"red\", \":green\"], f: %{tar_vis: \"blue\"}, j: \":sonic\"}]\n\niex> transmogrify([\n...>     %{a: 1,\n...>       b: [\"red\", nil, \"\", [], \":green\"],\n...>       c: [], d: nil, e: \"\",\n...>       f: %{TarDis: \"blue\"},\n...>       j: \":sonic\"}, 10\n...>   ],\n...>   value_convert: :semi_atom\n...> )\n[%{ a: 1, b: [\"red\", nil, \"\", [], :green], f: %{TarDis: \"blue\"}, j: :sonic, c: [], d: nil, e: \"\"}, 10]\n\niex> transmogrify(%{key1: 10, keyTwo: \"foo\"}, key_convert: :string)\n%{\"key1\" => 10, \"keyTwo\" => \"foo\"}\n\niex> transmogrify(%{key1: 10, keyTwo: \"foo\"}, key_convert: :string, key_case: :snake)\n%{\"key1\" => 10, \"key_two\" => \"foo\"}\n```","ref":"Transmogrify.Transmogrifier.html#transmogrify/2"},{"type":"extras","title":"Transmogrify","doc":"# Transmogrify\n\nElixir module which accepts data with different shapes and changes them to an\nexpected shape, such as switching keys in a map to camel case, or all string\nkeys to atom keys, etc.\n\nFull docs found at:  .","ref":"readme.html"},{"type":"extras","title":"Installation - Transmogrify","doc":"The package can be installed by adding `transmogrify` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:transmogrify, \"~> 1.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown"}